The default configuration files in this directory where generated by
creating a new design in the Renesas GreenPAK designer and exporting its
NVM value as a hex file. They represent 'safe' default configurations
and may be different from the configuration prorgrammed in the factory..
